@@ -18,4 +18,4 @@ class DefocusAnalyzeResult:
     reference_image_file_ids: list[str]
     comparison_stopped_on_index: int
     least_freq_diff: float | None
-    is_defocused: bool
+    certainty: float
